# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import uuid
import pydantic
import datetime as dt
import typing


class Category(UniversalBaseModel):
    id: uuid.UUID = pydantic.Field()
    """
    Unique identifier for the category
    """

    name: str = pydantic.Field()
    """
    Name of the category
    """

    color_hex: str = pydantic.Field()
    """
    Hex color code for the category
    """

    created_at: dt.datetime = pydantic.Field()
    """
    When the category was created
    """

    transcription_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of transcriptions in this category
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
