# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class RemoveKnowledgeBaseDocumentResponse(UniversalBaseModel):
    success: bool = pydantic.Field()
    """
    True if the document was successfully removed or was not present.
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional message describing the outcome (e.g., not found).
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
