# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class AudioChunk(UniversalBaseModel):
    """
    Binary chunk of PCM audio streamed from the client.
    """

    data: str = pydantic.Field()
    """
    PCM audio data chunk
    """

    mime_type: str

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
