# This file was auto-generated by Fern from our API Definition.

from .types import GenerateTranscriptSummaryRequest, TranscriptSummaryResponse

__all__ = ["GenerateTranscriptSummaryRequest", "TranscriptSummaryResponse"]
