# This file was auto-generated by Fern from our API Definition.

import enum


class SoferAIEnvironment(enum.Enum):
    PRODUCTION = "https://api.sofer.ai"
    STAGING = "https://api-staging.sofer.ai"
    DEVELOPMENT = "http://localhost:8001"
