# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .timestamp import Timestamp
import pydantic
from .language import Language


class UpdateTimestampsRequest(UniversalBaseModel):
    old_timestamps: typing.List[Timestamp] = pydantic.Field()
    """
    The original timestamps associated with the text before editing. These will be used as reference points to align the new timestamps.
    """

    edited_text: str = pydantic.Field()
    """
    The modified version of the transcription text that needs updated timestamp alignments. This should be the complete text after your edits.
    """

    language_to_update: Language = pydantic.Field()
    """
    Specifies which language version of the timestamps to update. Must be either 'en' for English or 'he' for Hebrew timestamps.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
