# This file was auto-generated by Fern from our API Definition.

from .duration_request import DurationRequest
from .duration_response import DurationResponse

__all__ = ["DurationRequest", "DurationResponse"]
