# This file was auto-generated by Fern from our API Definition.

import typing
from .environment import SoferAIEnvironment
import os
import httpx
from .core.client_wrapper import SyncClientWrapper
from .balance.client import BalanceClient
from .categories.client import CategoriesClient
from .health.client import HealthClient
from .link.client import LinkClient
from .maishiv.client import MaishivClient
from .timestamps.client import TimestampsClient
from .transcribe.client import TranscribeClient
from .transformations.client import TransformationsClient
from .utils.client import UtilsClient
from .core.client_wrapper import AsyncClientWrapper
from .balance.client import AsyncBalanceClient
from .categories.client import AsyncCategoriesClient
from .health.client import AsyncHealthClient
from .link.client import AsyncLinkClient
from .maishiv.client import AsyncMaishivClient
from .timestamps.client import AsyncTimestampsClient
from .transcribe.client import AsyncTranscribeClient
from .transformations.client import AsyncTransformationsClient
from .utils.client import AsyncUtilsClient


class SoferAI:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : SoferAIEnvironment
        The environment to use for requests from the client. from .environment import SoferAIEnvironment



        Defaults to SoferAIEnvironment.PRODUCTION



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from soferai import SoferAI

    client = SoferAI(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: SoferAIEnvironment = SoferAIEnvironment.PRODUCTION,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = os.getenv("SOFERAI_API_KEY"),
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.balance = BalanceClient(client_wrapper=self._client_wrapper)
        self.categories = CategoriesClient(client_wrapper=self._client_wrapper)
        self.health = HealthClient(client_wrapper=self._client_wrapper)
        self.link = LinkClient(client_wrapper=self._client_wrapper)
        self.maishiv = MaishivClient(client_wrapper=self._client_wrapper)
        self.timestamps = TimestampsClient(client_wrapper=self._client_wrapper)
        self.transcribe = TranscribeClient(client_wrapper=self._client_wrapper)
        self.transformations = TransformationsClient(client_wrapper=self._client_wrapper)
        self.utils = UtilsClient(client_wrapper=self._client_wrapper)


class AsyncSoferAI:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : SoferAIEnvironment
        The environment to use for requests from the client. from .environment import SoferAIEnvironment



        Defaults to SoferAIEnvironment.PRODUCTION



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from soferai import AsyncSoferAI

    client = AsyncSoferAI(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: SoferAIEnvironment = SoferAIEnvironment.PRODUCTION,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = os.getenv("SOFERAI_API_KEY"),
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.balance = AsyncBalanceClient(client_wrapper=self._client_wrapper)
        self.categories = AsyncCategoriesClient(client_wrapper=self._client_wrapper)
        self.health = AsyncHealthClient(client_wrapper=self._client_wrapper)
        self.link = AsyncLinkClient(client_wrapper=self._client_wrapper)
        self.maishiv = AsyncMaishivClient(client_wrapper=self._client_wrapper)
        self.timestamps = AsyncTimestampsClient(client_wrapper=self._client_wrapper)
        self.transcribe = AsyncTranscribeClient(client_wrapper=self._client_wrapper)
        self.transformations = AsyncTransformationsClient(client_wrapper=self._client_wrapper)
        self.utils = AsyncUtilsClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: SoferAIEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")
