# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .timestamp import Timestamp
from .transcription_info import TranscriptionInfo


class Transcription(UniversalBaseModel):
    text: str = pydantic.Field()
    """
    This field contains the transcription text. If the `primary_language` is English and only one `hebrew_word_format` is specified, the text will be in English with Hebrew words in the specified format. If multiple `hebrew_word_format` options are set, Hebrew words will appear in both formats, with the English transliteration in <i>Italics</i>. If the primary language is Hebrew, the text will be in Hebrew.
    """

    timestamps: typing.Optional[typing.List[Timestamp]] = pydantic.Field(default=None)
    """
    Timestamps object for the transcription. See the `timestamps` object for more details.
    """

    info: TranscriptionInfo = pydantic.Field()
    """
    Additional information about the transcription
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
