# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic


class DurationRequest(UniversalBaseModel):
    audio_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Direct URL to a downloadable audio file.
    """

    audio_file: typing.Optional[str] = pydantic.Field(default=None)
    """
    Base64-encoded audio file content. Do not include a data URI prefix.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
