# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .letters_language import LettersLanguage


class Timestamp(UniversalBaseModel):
    word: str = pydantic.Field()
    """
    Word
    """

    hebrew_word_format: typing.Optional[typing.List[LettersLanguage]] = pydantic.Field(default=None)
    """
    Specifies the format of Hebrew words in the transcription. Hebrew words are denoted as "he" for Hebrew letters or "en" for English transliteration. Non-Hebrew words are represented by null.
    """

    start: float = pydantic.Field()
    """
    Start time of the timestamp
    """

    end: float = pydantic.Field()
    """
    End time of the timestamp
    """

    speaker: typing.Optional[str] = pydantic.Field(default=None)
    """
    If speaker labeling was requested, indicates which speaker number spoke this word (Pro feature)
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
