# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import uuid
import typing


class AddTranscriptionToCategoryResponse(UniversalBaseModel):
    message: str = pydantic.Field()
    """
    Success message
    """

    category_id: uuid.UUID = pydantic.Field()
    """
    ID of the category
    """

    transcription_id: uuid.UUID = pydantic.Field()
    """
    ID of the transcription
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
