# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class DurationResponse(UniversalBaseModel):
    duration_seconds: float = pydantic.Field()
    """
    Duration of the audio in seconds. Returns 0 if the duration cannot be determined.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
