# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import uuid
import pydantic
import typing


class AddTranscriptionToCategoryRequest(UniversalBaseModel):
    transcription_id: uuid.UUID = pydantic.Field()
    """
    ID of the transcription to add to the category
    """

    position: typing.Optional[int] = pydantic.Field(default=None)
    """
    Optional position within the category for ordering
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
