# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing


class CreateCategoryRequest(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    Name of the category
    """

    color_hex: typing.Optional[str] = pydantic.Field(default=None)
    """
    Hex color code for the category (e.g.,
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
